@@ -28,7 +28,11 @@ import Control.Concurrent (myThreadId)
 import System.Posix.Process (getProcessID)
 #endif
 
+#if MIN_VERSION_time(1,5,0)
+import Data.Time.Format (defaultTimeLocale)
+#else
 import System.Locale (defaultTimeLocale)
+#endif
 import Data.Time (getZonedTime,getCurrentTime,formatTime)
 
 import System.Log
