@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {- |
    Module     : System.Log.Handler.Log4jXML
    Copyright  : Copyright (C) 2007-2011 John Goerzen
@@ -109,7 +110,11 @@ import Control.Concurrent (ThreadId, myThreadId)  -- myThreadId is GHC only!
 import Control.Concurrent.MVar
 import Data.List (isPrefixOf)
 import System.IO
+#if MIN_VERSION_time(1,5,0)
+import Data.Time.Format (defaultTimeLocale)
+#else
 import System.Locale (defaultTimeLocale)
+#endif
 import Data.Time
 import System.Log
 import System.Log.Handler
